# This package is based on **Fermat's technique** to _factorize_ integers
Additionally, this package has the following methods :
1. prime_check: Check if an integer is prime or not by utilising Fermat's Factorising method
2. primes_in_range: Return a list of prime numbers within a specified range given by user input